summaryrefslogtreecommitdiffstats
path: root/kjs/regexp.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /kjs/regexp.cpp
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjs/regexp.cpp')
-rw-r--r--kjs/regexp.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kjs/regexp.cpp b/kjs/regexp.cpp
index 06defcc53..c10911693 100644
--- a/kjs/regexp.cpp
+++ b/kjs/regexp.cpp
@@ -38,7 +38,7 @@ RegExp::UTF8SupportState RegExp::utf8Support = RegExp::Unknown;
RegExp::RegExp(const UString &p, int f)
: pat(p), flgs(f), m_notEmpty(false), valid(true), buffer(0), originalPos(0)
{
// Determine whether libpcre has unicode support if need be..
#ifdef PCRE_CONFIG_UTF8
if (utf8Support == Unknown) {
int supported;
@@ -64,13 +64,13 @@ RegExp::RegExp(const UString &p, int f)
escape = false;
// we only care about \u
if (c == 'u') {
// standard unicode escape sequence looks like \uxxxx but
// other browsers also accept less then 4 hex digits
unsigned short u = 0;
int j = 0;
for (j = 0; j < 4; ++j) {
- if (i + 1 < p.size() && Lexer::isHexDigit(p[i + 1].unicode())) {
- u = (u << 4) + Lexer::convertHex(p[i + 1].unicode());
+ if (i + 1 < p.size() && Lexer::isHexDigit(p[i + 1].tqunicode())) {
+ u = (u << 4) + Lexer::convertHex(p[i + 1].tqunicode());
++i;
} else {
// sequence incomplete. restore index.
@@ -222,7 +222,7 @@ void RegExp::prepareUtf8(const UString& s)
int *posOut = originalPos;
const UChar *d = s.data();
for (int i = 0; i != length; ++i) {
- unsigned short c = d[i].unicode();
+ unsigned short c = d[i].tqunicode();
int sequenceLen;
if (c < 0x80) {
@@ -38,7 +38,7 @@ RegExp::UTF8SupportState RegExp::utf8Support = RegExp::Unknown;
: pat(p), flgs(f), m_notEmpty(false), valid(true), buffer(0), originalPos(0)
{
- // Determine whether libpcre has unicode support if need be..
+ // Determine whether libpcre has tqunicode support if need be..
#ifdef PCRE_CONFIG_UTF8
if (utf8Support == Unknown) {
@@ -64,13 +64,13 @@ RegExp::RegExp(const UString &p, int f)
// we only care about \u
if (c == 'u') {
- // standard unicode escape sequence looks like \uxxxx but
+ // standard tqunicode escape sequence looks like \uxxxx but
// other browsers also accept less then 4 hex digits
unsigned short u = 0;